( cd usr/lib ; rm -rf libtclx.a )
( cd usr/lib ; ln -sf libtclx8.3.a libtclx.a )
( cd usr/lib ; rm -rf libtkx.a )
( cd usr/lib ; ln -sf libtkx8.3.a libtkx.a )
( cd usr/lib ; rm -rf libtclx.so )
( cd usr/lib ; ln -sf libtclx8.3.so libtclx.so )
( cd usr/lib ; rm -rf libtkx.so )
( cd usr/lib ; ln -sf libtkx8.3.so libtkx.so )
( cd usr/man/man3 ; rm -rf TclX_KeyedListGet.3.gz )
( cd usr/man/man3 ; ln -sf TclX_KeyedListDelete.3.gz TclX_KeyedListGet.3.gz )
( cd usr/man/man3 ; rm -rf TclX_KeyedListGetKeys.3.gz )
( cd usr/man/man3 ; ln -sf TclX_KeyedListDelete.3.gz TclX_KeyedListGetKeys.3.gz )
( cd usr/man/man3 ; rm -rf TclX_KeyedListSet.3.gz )
( cd usr/man/man3 ; ln -sf TclX_KeyedListDelete.3.gz TclX_KeyedListSet.3.gz )
( cd usr/man/man3 ; rm -rf TclX_NewKeyedListObj.3.gz )
( cd usr/man/man3 ; ln -sf TclX_KeyedListDelete.3.gz TclX_NewKeyedListObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_HandleFree.3.gz )
( cd usr/man/man3 ; ln -sf Tcl_HandleAlloc.3.gz Tcl_HandleFree.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_HandleTblInit.3.gz )
( cd usr/man/man3 ; ln -sf Tcl_HandleAlloc.3.gz Tcl_HandleTblInit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_HandleTblUseCount.3.gz )
( cd usr/man/man3 ; ln -sf Tcl_HandleAlloc.3.gz Tcl_HandleTblUseCount.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_HandleWalk.3.gz )
( cd usr/man/man3 ; ln -sf Tcl_HandleAlloc.3.gz Tcl_HandleWalk.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_HandleXlate.3.gz )
( cd usr/man/man3 ; ln -sf Tcl_HandleAlloc.3.gz Tcl_HandleXlate.3.gz )
( cd usr/man/man3 ; rm -rf Tclx_Init.3.gz )
( cd usr/man/man3 ; ln -sf TclX_Main.3.gz Tclx_Init.3.gz )
( cd usr/man/man3 ; rm -rf Tclxcmd_Init.3.gz )
( cd usr/man/man3 ; ln -sf TclX_Main.3.gz Tclxcmd_Init.3.gz )
( cd usr/man/man3 ; rm -rf TkX_Main.3.gz )
( cd usr/man/man3 ; ln -sf TclX_Main.3.gz TkX_Main.3.gz )
( cd usr/man/man3 ; rm -rf Tkx_Init.3.gz )
( cd usr/man/man3 ; ln -sf TclX_Main.3.gz Tkx_Init.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_HandleTblRelease.3.gz )
( cd usr/man/man3 ; ln -sf Tcl_HandleAlloc.3.gz Tcl_HandleTblRelease.3.gz )
( cd usr/man/mann ; rm -rf Tcl_InitMemory.n.gz )
( cd usr/man/mann ; ln -sf Tcl_DisplayMemory.n.gz Tcl_InitMemory.n.gz )
( cd usr/man/mann ; rm -rf Tcl_ValidateAllMemory.n.gz )
( cd usr/man/mann ; ln -sf Tcl_DisplayMemory.n.gz Tcl_ValidateAllMemory.n.gz )
( cd usr/man/mann ; rm -rf ckalloc.n.gz )
( cd usr/man/mann ; ln -sf Tcl_DisplayMemory.n.gz ckalloc.n.gz )
( cd usr/man/mann ; rm -rf ckfree.n.gz )
( cd usr/man/mann ; ln -sf Tcl_DisplayMemory.n.gz ckfree.n.gz )
( cd usr/man/mann ; rm -rf memory.n.gz )
( cd usr/man/mann ; ln -sf Tcl_DisplayMemory.n.gz memory.n.gz )
